@@ -16,7 +16,7 @@ Usage::
     session_client: SageMakerRuntimeClient = session.client("sagemaker-runtime")
     ```
 """
-from mypy_boto3_sagemaker_runtime.client import SageMakerRuntimeClient
+from .client import SageMakerRuntimeClient
 
 Client = SageMakerRuntimeClient
 
