@@ -13,7 +13,7 @@ Usage::
 """
 import sys
 
-if sys.version_info >= (3, 8):
+if sys.version_info >= (3, 9):
     from typing import Literal
 else:
     from typing_extensions import Literal
@@ -55,6 +55,7 @@ ServiceName = Literal[
     "ce",
     "chime",
     "chime-sdk-identity",
+    "chime-sdk-meetings",
     "chime-sdk-messaging",
     "cloud9",
     "cloudcontrol",
@@ -221,6 +222,7 @@ ServiceName = Literal[
     "opsworkscm",
     "organizations",
     "outposts",
+    "panorama",
     "personalize",
     "personalize-events",
     "personalize-runtime",
